// NOTE! This code is for demonstration purposes only and does not contain any kind of
// 		 error handling. MUST be revised before using in production.

"use strict";

function OnNewShellUI( shellUI )
{
	// This is the start point of a ShellUI module.
	
	// Register to be notified when a new normal shell frame (Event_NewNormalShellFrame) is created.
	// We use Event_NewNormalShellFrame rather than Event_NewShellFrame as this won't fire for history (etc.) dialogs.
	// ref: https://www.m-files.com/UI_Extensibility_Framework/index.html#Event_NewNormalShellFrame.html
	shellUI.Events.Register(
		Event_NewNormalShellFrame,
		handleNewNormalShellFrame);
}

function handleNewNormalShellFrame(shellFrame)
{
	/// <summary>Handles the OnNewNormalShellFrame event for an IShellUI.</summary>
	/// <param name="shellFrame" type="MFiles.ShellFrame">The shell frame object which was created.</param> 

	// The shell frame was created but it cannot be used yet.
	// The following line would throw an exception ("The object cannot be accessed, because it is not ready."):
	// shellFrame.ShowMessage("A shell frame was created");

	// Register to be notified when the shell frame is started.
	// This time pass a reference to the function to call when the event is fired.
	shellFrame.Events.Register(
		Event_Started,
		getShellFrameStartedHandler(shellFrame) );
}

function getShellFrameStartedHandler(shellFrame)
{
	/// <summary>Returns a function that handles the OnStarted event for an IShellFrame.</summary>

	return function()
	{
		// The shell frame is now started and can be used.
		var dashboardId = "TestSearchPanel";
		// Create a new tab for the content to be shown in.
		// ref: https://www.m-files.com/UI_Extensibility_Framework/index.html#MFClientScript~IShellPaneContainer~AddTab.html
		// Tab ids ref: https://www.m-files.com/UI_Extensibility_Framework/#SidePaneTabs.html
		var tab = shellFrame.RightPane.AddTab(dashboardId, "Test Search", "_last" );

		
		
		// Create the custom data object.
		var customDataObject = {
			// Create a property named "myFunction" and assign it the function to call.
			// This function defines one parameter, but it could have any number.
			shellFrame: shellFrame,
			testcreateView: function(dashboard){
				var oView = new MFiles.View();
				var oSc = new MFiles.SearchCriteria();
				oSc.SearchFlags = MFSearchFlags.MFSearchFlagNone;
				oSc.ExpandUI = false;
				
				// Create the search condition.
				var scex = new MFiles.SearchConditionEx();
				var sc = new MFiles.SearchCondition();
				
				oView.Name = "TestCustSearchView";
				sc.Expression.SetPropertyValueExpression(
					1067, //Property ID 1067 -> Company
					MFParentChildBehavior.MFParentChildBehaviorNone,
					new MFiles.DataFunctionCall() 
					);
				
				sc.ConditionType = MFConditionType.MFConditionTypeEqual;
				
				var lookup1 = new MFiles.Lookup()
				{
					ObjectType = 106, //Value Lists ID 106 -> Companies
					Item = 1 //Item ID in value list
				};	
				var lookup2 = new MFiles.Lookup()
				{
					ObjectType = 106, 
					Item = 2 
				};	
				var lookups = new MFiles.Lookups();
				lookups.add(-1, lookup1);
				lookups.add(-1, lookup2);
				sc.TypedValue.SetValueToMultiSelectLookup(lookups);
				scex.Set(sc, true, false, false);
				oSc.AdditionalConditions.Add(-1, scex);
				
				oView = dashboard.Vault.ViewOperations.AddTemporarySearchViewEx(oView, oSc, false);
				
				var fd1 = new MFiles.FolderDef();
				fd1.SetView(MFBuiltInView.MFBuiltInViewLatestSearches); 
				var fd = new MFiles.FolderDef();
				fd.SetView(oView.ID);
				var fds = new MFiles.FolderDefs();
				fds.Add(0,fd1);
				fds.Add(0,fd);
				shellFrame.NavigateToFolder(fds);
			}
		};
		 
		// Show the dashboard.
		tab.ShowDashboard(dashboardId, customDataObject);
		
		// Show the tab.
		tab.visible = true;
		tab.Select();
	}
};


